###################################################
### chunk number 1: 
###################################################
options(width = 50, digits = 2, scipen = 5)
set.seed(1)
cat.df.without.rownames <- function (d, file = ""){
  stopifnot(is.data.frame(d))
  row.names(d) <- 1:nrow(d)
  x <- NULL
  conn <- textConnection("x", "w", local = TRUE)
  capture.output(print(d), file = conn)
  close(conn)
  cat(substring(x, first = max(nchar(row.names(d))) + 2), sep = "\n", 
      file = file)
}


###################################################
### chunk number 2: 
###################################################
library(backtest)


###################################################
### chunk number 3: 
###################################################
data(starmine)
names(starmine)


###################################################
### chunk number 4: 
###################################################
cat.df.without.rownames(as.data.frame.table(table(date = as.character(starmine$date)), responseName = "count"))


###################################################
### chunk number 5: 
###################################################
current.options <- options(digits = 1, width = 80, scipen = 99)


###################################################
### chunk number 6: 
###################################################
cat.df.without.rownames(starmine[row.names(starmine) %in% c(2254, 9852, 10604, 18953, 62339, 77387, 85739), c("date", "name", "ret.0.1.m", "ret.0.6.m","smi")])


###################################################
### chunk number 7: 
###################################################
options(current.options)


###################################################
### chunk number 8: 
###################################################
bt <- backtest(starmine, in.var = "smi", ret.var = "ret.0.1.m", by.period = FALSE)


###################################################
### chunk number 9: 
###################################################
table(cut(starmine$smi, breaks = quantile(starmine$smi, probs=seq(0,1,0.20), 
                          na.rm=TRUE, 
                          names=TRUE), 
          include.lowest = TRUE))


###################################################
### chunk number 10: 
###################################################
summary(bt)


###################################################
### chunk number 11: natural portfolio
###################################################
bt <- backtest(starmine, id.var = "id",
               date.var = "date", in.var = "smi",
               ret.var = "ret.0.1.m", natural = TRUE, by.period = FALSE)


###################################################
### chunk number 12: 
###################################################
current.options <- options()
options(digits = 1, width = 80)


###################################################
### chunk number 13: summary natural backtest
###################################################
summary(bt)


###################################################
### chunk number 14: 
###################################################
options(current.options)


###################################################
### chunk number 15: 
###################################################
op <- options(digits = 1)


###################################################
### chunk number 16: smi.2 backtest
###################################################
bt <- backtest(starmine,
                     id.var = "id",
                     date.var = "date",
                     in.var = c("smi", "cap.usd"),
                     ret.var = "ret.0.1.m",
                     natural = TRUE,
                     by.period = FALSE)


###################################################
### chunk number 17: 
###################################################
bt.save <- bt


###################################################
### chunk number 18: 
###################################################
summary(bt)


###################################################
### chunk number 19: 
###################################################
options(op)


###################################################
### chunk number 20: 
###################################################
plot(bt, type = "return")


###################################################
### chunk number 21: 
###################################################
plot(bt.save, type = "cumreturn.split")


###################################################
### chunk number 22: 
###################################################
plot(bt, type = "turnover")


###################################################
### chunk number 23: 
###################################################
current.options <- options()
options(digits = 1, width = 50)


###################################################
### chunk number 24: sector backtest
###################################################
bt <- backtest(starmine, in.var = "smi", ret.var = "ret.0.1.m", by.var = "sector", by.period = FALSE)


###################################################
### chunk number 25: 
###################################################
options(width = 80)


###################################################
### chunk number 26: 
###################################################
summary(bt)


###################################################
### chunk number 27: 
###################################################
options(current.options)


###################################################
### chunk number 28: counts
###################################################
counts(bt)


###################################################
### chunk number 29: 
###################################################
current.options <- options()
options(digits = 1, width = 30)


###################################################
### chunk number 30: market cap
###################################################
bt <- backtest(starmine, in.var = "smi", ret.var = "ret.0.1.m", by.var = "cap.usd", buckets = c(5, 10), by.period = FALSE)


###################################################
### chunk number 31: 
###################################################
options(current.options)


###################################################
### chunk number 32: 
###################################################
summary(bt)


###################################################
### chunk number 33: 
###################################################
bt <- backtest(starmine, in.var = "smi", buckets = 4,
               ret.var = c("ret.0.1.m", "ret.0.6.m"), by.period = FALSE)


###################################################
### chunk number 34: 
###################################################
op <- options(width = 80)


###################################################
### chunk number 35: 
###################################################
summary(bt)


###################################################
### chunk number 36: 
###################################################
options(op)


